/* 
Replication file for Braithwaite & Chu (2017)
"Civil conflicts abroad, foreign fighters, and terrorism at home"
*/

*Establish working directory
cd /Volumes/tchu/Dropbox/Collaborations/Terrorism_FFs/JCR_FinalSubmission/


use "ChuBraithwaite_ConfTerrFFs2017_data.dta"
set more off
sort ccode year


***Establish the sample being used:
nbreg F.GTD slc_rebvictory_ff slc_rebdefeat_ff CivilWarOngoing democracy logGNI logpop GINI AggSF ColdWar t_GTD t2_GTD t3_GTD, cl(ccode) nolog

*** Table 1: Summary Statistics
sutex2 GTD groupst conflicts_ffs slc_rebvictory_ff slc_rebdefeat_ff CivilWarOngoing democracy logGNI logpop GINI AggSF ColdWar t_GTD t2_GTD t3_GTD emergeyrs emergeyrs2 emergeyrs3 if e(sample)==1, minmax

*** Table 2: Main Models
*MODEL 1: Baseline plus Global 
nbreg F.GTD conflicts_ffs CivilWarOngoing democracy logGNI logpop GINI AggSF ColdWar t_GTD t2_GTD t3_GTD if e(sample)==1, cl(ccode) nolog
estat ic
listcoef, help percent
*FIGURE 2
coefplot, drop(_cons t2_GTD t3_GTD) xline(0) coeflabels(conflicts_ffs = "Ongoing Conflicts w/ FFs" CivilWarOngoing = "Ongoing Civil Conflict at Home" democracy = "Democracy" logGNI = "Logged GNI" logpop = "Logged Population" GINI = "Income Inequality" AggSF = "State Failure" ColdWar = "Cold War Years" t_GTD = "Years Since Last Terrorism")  headings(conflicts_ffs = "{bf: Conflict Abroad}" CivilWarOngoing = "{bf: Standard Controls}" ColdWar = "{bf: Temporal Trends}") graphregion(color(white)) scheme(s2mono)


*MODEL 2: Baseline plus Spatial lag
nbreg F.GTD slc_rebvictory_ff slc_rebdefeat_ff CivilWarOngoing democracy logGNI logpop GINI AggSF ColdWar t_GTD t2_GTD t3_GTD if e(sample)==1, cl(ccode) nolog
estat ic
listcoef, help percent
*FIGURE3
coefplot, drop(_cons t2_GTD t3_GTD) xline(0) coeflabels(slc_rebvictory_ff = "Rebel Victory w/ FFs" slc_rebdefeat_ff = "Rebel Defeat w/ FFs" CivilWarOngoing = "Ongoing Civil Conflict at Home" democracy = "Democracy" logGNI = "Logged GNI" logpop = "Logged Population" GINI = "Income Inequality" AggSF = "State Failure" ColdWar = "Cold War Years" t_GTD = "Years Since Last Terrorism")  headings(slc_rebvictory_ff = "{bf: Conflict Abroad}" CivilWarOngoing = "{bf: Standard Controls}" ColdWar = "{bf: Temporal Trends}") graphregion(color(white)) scheme(s2mono)

*MODEL 3: With placebo instead
nbreg F.GTD slc_rebvictory_p slc_rebdefeat_p CivilWarOngoing democracy logGNI logpop GINI AggSF ColdWar t_GTD t2_GTD t3_GTD if e(sample)==1, cl(ccode) nolog
estat ic
listcoef, help percent

* MODEL 4: With region controls; baseline is Europe and the americas
nbreg F.GTD slc_rebvictory_ff slc_rebdefeat_ff CivilWarOngoing democracy logGNI logpop GINI AggSF ColdWar ssafrica asia nafrme t_GTD t2_GTD t3_GTD, cl(ccode) nolog
estat ic
listcoef, help percent

*** Table 3: "New" and "Old" Terrorism problems

*MODEL 5: zero-inflated negative binomials

zinb GTD slc_rebvictory_ff slc_rebdefeat_ff CivilWarOngoing democracy logGNI logpop GINI AggSF ColdWar t_GTD t2_GTD t3_GTD if e(sample)==1, inflate(slc_rebvictory_ff slc_rebdefeat_ff CivilWarOngoing democracy logGNI logpop GINI AggSF ColdWar t_GTD t2_GTD t3_GTD) cl(ccode) nolog

*MODELS 6:  DV = New Group Emergence: All groups

logit groupst slc_rebvictory_ff slc_rebdefeat_ff CivilWarOngoing democracy logGNI logpop GINI AggSF ColdWar emergeyrs emergeyrs2 emergeyrs3 if e(sample)==1, cl(ccode) nolog
